OpenLogger class

Constructors

OpenLogger({required String token, required String url, bool autoConfig = false})

Properties

autoConfig → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
final
url → String
final

Methods

log({required String type, required String message, Map<String, dynamic>? data, String? app, String? url, String? userid, String? username, String? schema, String? reference}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited